==> mozilla-source-0.9.8.tar.gz: mozilla/extensions/wallet/src/nsPassword.cpp <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsPassword.h"
#include "nsString.h"
#include "prmem.h"

// nsPassword Implementation

NS_IMPL_ISUPPORTS2(nsPassword, nsIPassword, nsISupportsWeakReference);

nsPassword::nsPassword() {
  NS_INIT_REFCNT();
}

nsPassword::nsPassword(char * host, PRUnichar * user, PRUnichar * pswd) {
  passwordHost = host;
  passwordUser = user;
  passwordPswd = pswd;
  NS_INIT_REFCNT();
}

nsPassword::~nsPassword(void) {
  CRTFREEIF(passwordHost);
  CRTFREEIF(passwordUser);
  CRTFREEIF(passwordPswd);
}

NS_IMETHODIMP nsPassword::GetHost(char * *aHost) {
  if (passwordHost) {
    *aHost = (char *) nsMemory::Clone(passwordHost, nsCRT::strlen(passwordHost) + 1);
    return NS_OK;
  }
  return NS_ERROR_NULL_POINTER;
}

NS_IMETHODIMP nsPassword::GetUser(PRUnichar * *aUser) {
  if (passwordUser) {
    *aUser = (PRUnichar *) nsMemory::Clone(passwordUser, 2*(nsCRT::strlen(passwordUser) + 1));
    return NS_OK;
  }
  return NS_ERROR_NULL_POINTER;
}

NS_IMETHODIMP nsPassword::GetPassword(PRUnichar * *aPswd) {
  if (passwordPswd) {
    *aPswd = (PRUnichar *) nsMemory::Clone(passwordPswd, 2*(nsCRT::strlen(passwordPswd) + 1));
    return NS_OK;
  }
  return NS_ERROR_NULL_POINTER;
}

==> mozilla-source-1.2.tar.gz: mozilla/extensions/wallet/src/nsPassword.cpp <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsPassword.h"
#include "nsString.h"
#include "nsCRT.h"
#include "prmem.h"

// nsPassword Implementation

NS_IMPL_ISUPPORTS2(nsPassword, nsIPassword, nsISupportsWeakReference);

nsPassword::nsPassword() {
  NS_INIT_ISUPPORTS();
}

nsPassword::nsPassword(char * host, PRUnichar * user, PRUnichar * pswd) {
  passwordHost = host;
  passwordUser = user;
  passwordPswd = pswd;
  NS_INIT_ISUPPORTS();
}

nsPassword::~nsPassword(void) {
  CRTFREEIF(passwordHost);
  CRTFREEIF(passwordUser);
  CRTFREEIF(passwordPswd);
}

NS_IMETHODIMP nsPassword::GetHost(nsACString& aHost) {
//NS_IMETHODIMP nsPassword::GetHost(nsAUTF8String& aHost) {
// using nsACString above instead of nsAUTF8String because the latter doesn't exist yet
  if (passwordHost) {
    aHost = passwordHost;
    return NS_OK;
  }
  return NS_ERROR_NULL_POINTER;
}

NS_IMETHODIMP nsPassword::GetUser(nsAString& aUser) {
  if (passwordUser) {
    aUser = passwordUser;
    return NS_OK;
  }
  return NS_ERROR_NULL_POINTER;
}

NS_IMETHODIMP nsPassword::GetPassword(nsAString& aPswd) {
  if (passwordPswd) {
    aPswd = passwordPswd;
    return NS_OK;
  }
  return NS_ERROR_NULL_POINTER;
}
